<?php
/*
Plugin Name: Simple URL to QR Code
Plugin URI: https://wordpress.org/plugins/simple-url-to-qr-code/
Description: A plugin to generate QR codes for any URL directly from your WordPress dashboard.
Version: 1.1
Author: agataphp
Author URI: https://profiles.wordpress.org/agataphp/
License: GPLv2 or later
Text Domain: simple-url-to-qr-code
Domain Path: /languages
*/

defined('ABSPATH') || exit;

// Load translations
add_action('init', 'sutq_load_textdomain');
function sutq_load_textdomain() {
    load_plugin_textdomain('simple-url-to-qr-code', false, dirname(plugin_basename(__FILE__)) . '/languages');
}

/**
 * Register plugin menu
 */
function sutq_add_admin_menu() {
    global $menu;
    add_menu_page(
        __('Simple URL to QR Code', 'simple-url-to-qr-code'),
        __('URL to QR Code', 'simple-url-to-qr-code'),
        'manage_options',
        'simple-url-to-qr-code',
        'sutq_render_admin_page',
        'data:image/svg+xml;base64,' . base64_encode('<svg width="20" height="20" viewBox="0 0 1024 1024" xmlns="http://www.w3.org/2000/svg"><path fill="black" d="M468 128H160c-17.7 0-32 14.3-32 32v308c0 4.4 3.6 8 8 8h332c4.4 0 8-3.6 8-8V136c0-4.4-3.6-8-8-8zm-56 284H192V192h220v220zm-138-74h56c4.4 0 8-3.6 8-8v-56c0-4.4-3.6-8-8-8h-56c-4.4 0-8 3.6-8 8v56c0 4.4 3.6 8 8 8zm96 210h308c4.4 0 8-3.6 8-8V332c0-4.4-3.6-8-8-8H370c-4.4 0-8 3.6-8 8v308c0 4.4 3.6 8 8 8zm56-308h220v220H426V240zm-56 392H162c-4.4 0-8 3.6-8 8v308c0 4.4 3.6 8 8 8h308c4.4 0 8-3.6 8-8V640c0-4.4-3.6-8-8-8zm-56 284H192V672h220v220zm-138-74h56c4.4 0 8-3.6 8-8v-56c0-4.4-3.6-8-8-8h-56c-4.4 0-8 3.6-8 8v56c0 4.4 3.6 8 8 8zm508-448h308c4.4 0 8-3.6 8-8V132c0-4.4-3.6-8-8-8H732c-4.4 0-8 3.6-8 8v308c0 4.4 3.6 8 8 8zm56-308h220v220H788V192zm-56 392h308c4.4 0 8-3.6 8-8V332c0-4.4-3.6-8-8-8H732c-4.4 0-8 3.6-8 8v308c0 4.4 3.6 8 8 8zm56-308h220v220H788V240z"/></svg>')
    );
}
add_action('admin_menu', 'sutq_add_admin_menu');

/**
 * Enqueue plugin assets
 */
function sutq_enqueue_assets() {
    $screen = get_current_screen();
    if ($screen && 'toplevel_page_simple-url-to-qr-code' === $screen->id) {
        wp_enqueue_style(
            'sutq-admin-styles',
            plugins_url('assets/css/sutq-admin.css', __FILE__),
            array(),
            '1.1'
        );

        wp_enqueue_script(
            'sutq-admin-script',
            plugins_url('assets/js/sutq-admin.js', __FILE__),
            array('jquery'),
            '1.1',
            true
        );

        wp_localize_script('sutq-admin-script', 'sutqAdmin', array(
            'copySuccess' => __('Copied!', 'simple-url-to-qr-code'),
            'copyButton' => __('Copy', 'simple-url-to-qr-code')
        ));
    }
}
add_action('admin_enqueue_scripts', 'sutq_enqueue_assets');

/**
 * Add settings link on plugin page
 */
function sutq_add_settings_link($links) {
    $settings_link = sprintf(
        '<a href="%s">%s</a>',
        admin_url('admin.php?page=simple-url-to-qr-code'),
        __('Settings', 'simple-url-to-qr-code')
    );
    array_unshift($links, $settings_link);
    return $links;
}
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'sutq_add_settings_link');

// Include required files
require_once plugin_dir_path(__FILE__) . 'includes/class-sutq-image-handler.php';
require_once plugin_dir_path(__FILE__) . 'includes/sutq-functions.php';

// Register shortcode
add_shortcode('sutq', 'sutq_shortcode_handler');